
*   Major: Select-able query implementations via `DistinctValuesQuery` enum.
*   Major: Introduce `PluginType.ConfiguratorPlugin` (e.g. to configure some values on GUI page).
*   Minor: Fix to avoid duplicates in the enum items.
*   Minor: Sort enum items (simplifies looking through and comparing the output).

*   Major: Initial implementation of FS_56_43_05_79 search in different collections.

*   Broken compatibility: rename `@/temp/` -> `@/tmp/`.
*   Broken compatibility: rename `use_mongomock_only` -> `use_mongomock`.
*   Broken compatibility: replace `next_interp_plugin_instance_id` by `tree_abs_path_to_interp_id`.

*   Test infra: initial implementation of FS_62_25_92_06 generated config.
